@@ -108,12 +108,12 @@ def cos(ad):
 
     EXAMPLES
     =========
-    >>> from autodiffpy import autodiffmod as autodiff
+    >>> from autodiffpy import autodiffmod as ad
     >>> from autodiffpy import autodiff_math as admath
-    >>> x = autodiff.autodiff('x', 10)
+    >>> x = ad.autodiff('x', 10)
     >>> f1 = admath.cos(x)
     >>> print(f1.val, f1.der)
-    [-0.83907153] {'x': 0.5440211108893698}
+    [-0.83907153] {'x': array([0.54402111])}
     """
     try:
         anew = autodiff.autodiff(name=ad.name, val = np.cos(ad.val), der = ad.der)
@@ -121,7 +121,7 @@ def cos(ad):
         anew.function = cos
 
         for key in ad.der:
-            if ad.der[key].shape == -1*np.sin(ad.val).shape:
+            if ad.der[key].shape == (-1*np.sin(ad.val)).shape:
                 anew.der[key] = ad.der[key]*-1*np.sin(ad.val)
             else:
                 anew.der[key] = np.dot(-1*np.sin(ad.val), ad.der[key])
